;* UNCONF.LSP
;
;* generic routine for user prompts to have default values
;
(defun DPRMPT (msg def / inp) 
   (if def 
      (setq msg (strcat "\n" msg "<" (rtos def) ">: ")) ;prompt string w/default
      (setq msg (strcat "\n" msg ": ")) ;prompt string w/o default
   ) 
   (setq inp (getreal msg))          ;prompt for user entry
   (if inp 
      inp 
      def
   )                                 ;return default if no user response
) 
;* EOFunc dprmpt
;*----------------------------------------------------------------------------
;* construct a polyline between user entered endpoints using a default
;* or a user specified vertex spacing.
;*----------------------------------------------------------------------------
(defun DPLINE (/ pt1 pt2 intv pdist xdist ydist xstart ystart) 
   (setq pt1 (getpoint "\nFirst Point: ")) ;get polyline endpoints
   (setq pt2 (getpoint "\nSecond Point: " pt1))
   (setq intv (dprmpt "\nEnter vertex interval: " 1000)) ;get vertex interval
   (setq pdist (distance pt1 pt2))   ;pdist = dist between pts
   (setq xdist (/ (- (car pt2) (car pt1)) pdist)) ;xdist = (x2-x1)/pdist
   (setq ydist (/ (- (cadr pt2) (cadr pt1)) pdist)) ;ydist = (y2-y1)/pdist
   (setq xstart (car pt1))           ;xstart = x1
   (setq ystart (cadr pt1))          ;ystart = y1
   (entmake (list (quote (0 . "POLYLINE")))) ;construct polyline header
   ;* construct polyline vertices
   (while (< (distance pt1 (list xstart ystart)) (distance pt1 pt2)) 
      (entmake (list (quote (0 . "VERTEX")) (list 10 xstart ystart 0.0))) 
      (setq xstart (+ xstart (* xdist intv)))
      (setq ystart (+ ystart (* ydist intv)))
   )                                 ;while
   ;* construct end of polyline marker
   (entmake (list (quote (0 . "VERTEX")) (list 10 (car pt2) (cadr pt2)))) 
   (entmake '((0 . "SEQEND")))
) 
;* EOFunc DPLINE
;*----------------------------------------------------------------------------
;* changes how Autocad fits a line between polyline verticies
;*----------------------------------------------------------------------------
(defun WAVE (/ bfac bulge1 bulge2 ename edata vtx) ; get first bulge factor, default = 1
   (setq bfac (dprmpt "\nEnter 1st bulge factor: " 1)) ; get second bulge factor, default = -1 * bfac
   (setq bfac1 (dprmpt "\nEnter 2nd bulge factor: " (* -1 bfac))) ;* select last entity in drawing
   (setq ename (entlast))            ;* process each vertex. assign alternating bulge factors.
   (progn
      (setq bulge1 (list (cons 42 bfac))) ;set positive bulge
      (setq bulge2 (list (cons 42 bfac1))) ;set negative bulge
      (setq vtx 1)                   ;start with positive bulge
      (while (and (setq ename (entnext ename))
                (setq edata (entget ename))
                (/= "SEQEND" (cdr (assoc 0 edata)))
             )                       ;and
         (cond
            ((= vtx 1) 
             (progn
                (setq edata (append edata bulge1))
                (setq vtx 2)
             )
            )                        ;case 1, add on pos bulge
            ((= vtx 2) 
             (progn
                (setq edata (append edata bulge2))
                (setq vtx 1)
             )
            )                        ;case 2, add on neg bulge
         )                           ;cond
         (entmod edata)              ;updates entity data description list
      )                              ;while
      (entupd ename)                 ;updates screen display
   )                                 ;progn
) 
;* EOFunc WAVE
;*----------------------------------------------------------------------------
;* define new Autocad command, draws a undulating polyline using DPLINE and
;* WAVE functions
;*----------------------------------------------------------------------------
(defun C:UNCONF ()                   ;* draw polyline between user entered points using a default or user
   ;* entered vertex interval.
   (dpline)                          ;* selects last drawing entity (DPLINE's polyline). applies a positive
   ;* bulge to the 1st vertex, a negative bulge to the 2nd vertex, back to
   ;* a positive bugle for the 3rd vertex and so on till the last vertex
   (wave) 
   (princ)                           ;clean exit, suppress any AutoLISP return messages
) 
;* EOProgram UNCONF

